<?php
/*
Plugin Name: mamap.io - Maps with searchbar
Description: Load your mamap.io map and allows you to embed your map anywhere using a shortcode.
Version: 1.0
Author: mamap.io
License: GPLv2 or later
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

// Enqueue the script in the footer
function mamap_enqueue_script() {
    $map_id = get_option('mamapio_id', '');
    if ($map_id) {
        wp_enqueue_script(
            'mamapio-script',
            "https://mamap.io/api/embed-map/" . esc_attr($map_id),
            [],
            null,
            true
        );
    }
}
add_action('wp_enqueue_scripts', 'mamap_enqueue_script');

// Create admin menu for settings
function mamap_create_menu() {
    add_menu_page(
        'mamap.io Settings',
        'mamap.io',
        'manage_options',
        'mamap-map-settings',
        'mamap_settings_page',
        'dashicons-location-alt',
        100
    );
}
add_action('admin_menu', 'mamap_create_menu');

// Register a setting for the map ID
function mamap_register_settings() {
    register_setting('mamap-settings-group', 'mamapio_id');
}
add_action('admin_init', 'mamap_register_settings');

// Add custom styles to the admin page
function mamap_admin_styles() {
    echo '<style>
        .mamap-logo {
            max-width: 80px;
            margin-bottom: 20px;
        }
        .mamap-settings-container {
            background: #f9f9f9;
            border: 1px solid #ddd;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }
        .mamap-settings-container h1 {
            font-size: 24px;
            margin-bottom: 10px;
        }
        .mamap-settings-container table th {
            text-align: left;
            font-weight: bold;
        }
        .mamap-settings-container table td {
            padding: 10px 0;
        }
        .mamap-settings-container input[type="text"] {
            width: 100%;
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 4px;
            box-sizing: border-box;
        }
        .mamap-settings-container .description {
            color: #666;
            font-size: 14px;
        }
    </style>';
}
add_action('admin_head', 'mamap_admin_styles');

// Admin settings page
function mamap_settings_page() {
    ?>
    <div class="wrap mamap-settings-container">
        <svg alt="mamap.io Logo" class="mamap-logo" id="Calque_1" xmlns="http://www.w3.org/2000/svg" version="1.1" viewBox="0 0 400 400">
        <rect width="400" height="400" fill="#6466e9"/>
        <g id="Calque_11" data-name="Calque_1">
            <g>
            <g id="q77v2y.tif">
                <path d="M238.8,135.3c0-1.5-.2-3-.4-4.5-3.4-20.4-22-34.7-42.6-32.3-14.4,1.7-24.8,9.3-31.1,22.4-2.2,4.7-3.5,9.5-3.6,14.4v.9c0,3.3.6,6.7,1.8,10,1.7,4.9,3.7,9.8,6,14.5,8.5,17,19.2,32.6,30.5,47.8,0,0,0,0,0,0,0,0,.1.1.2.2.1.1.2.2.4.4h0s0,0,.1,0c0,0,0,0,0-.1.3-.3.5-.6.7-.9.1-.2.2-.3.3-.4,7.1-9.6,13.9-19.4,20.1-29.6,5.1-8.3,9.9-16.7,13.6-25.7,2.2-5.3,3.7-10.6,3.8-16.2v-.9h0ZM214.5,137.4c0,8-6.5,14.5-14.5,14.5s-14.5-6.5-14.5-14.5,6.5-14.5,14.5-14.5,14.5,6.5,14.5,14.5Z" fill="#fff"/>
            </g>
            <g>
                <polygon points="199.9 225 199.9 225 199.9 225 199.9 225 199.9 225" fill="#fff"/>
                <polygon points="199.9 225 199.9 225 199.9 225 199.9 225 199.9 225 199.9 225" fill="#fff"/>
            </g>
            <g>
                <path d="M302.4,166.5v111c0,.5-.4.9-.9.9h-56.1c-.5,0-.9-.4-.9-.9v-60.5c0-.3-.4-.4-.6-.2l-43.8,62.2c0,0,0,0-.1,0,0,0,0,0-.1,0l-43.8-62.2c-.2-.3-.6-.1-.6.2v60.5c0,.5-.4.9-.9.9h-56.1c-.5,0-.9-.4-.9-.9v-111c0-11.7,7-22.3,17.8-26.9,13.1-5.6,28.4-1,36.1,11l48.3,74.3h.1v.2h0c0,0,0,0,0,0h.1c0-.1,48.3-74.5,48.3-74.5,7.8-12,23-16.6,36.1-11,10.8,4.6,17.8,15.2,17.8,26.9h0Z" fill="#fff"/>
                <polygon points="200.1 225 200.1 225 200.1 225 200.1 225 200.1 225" fill="#fff"/>
                <polygon points="200.1 225 200.1 225 200.1 225 200 225 200.1 225" fill="#fff"/>
            </g>
            <polygon points="199.9 225 199.9 225 199.9 225 199.9 225" fill="#fff"/>
            </g>
        </g>
        </svg>
        <h1>mamap.io Settings</h1>
        <form method="post" action="options.php">
            <?php settings_fields('mamap-settings-group'); ?>
            <?php do_settings_sections('mamap-settings-group'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Map ID</th>
                    <td>
                        <input type="text" name="mamapio_id" value="<?php echo esc_attr(get_option('mamapio_id')); ?>" />
                        <p class="description">Enter your map ID here.</p>
                        <p class="description">
                            Your map ID is the number found in your embed script in your mamap.io dashboard. For example, in the script: 
                            <code>&lt;script src="https://mamap.io/api/embed-map/&lt;your-map-id&gt;"&gt;&lt;/script&gt;</code>, 
                            the <code>&lt;your-map-id&gt;</code> is your map ID. 
                            <br><br>
                            Once you have entered your map ID here, you can add your map to any page, post, or article by using the shortcode <code>[mamapio]</code>. The map will automatically appear where the shortcode is placed.
                        </p>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Shortcode to embed the map div
function mamap_embed_shortcode($atts = [], $content = null) {
    $map_id = get_option('mamapio_id', '');
    if (!$map_id) {
        return '<p>Please configure the mamap.io plugin with a Map ID in the admin settings.</p>';
    }
    return '<div id="map' . esc_attr($map_id) . '" 
    title="Map powered by mamap.io" 
    aria-label="Interactive map powered by mamap.io" 
    style="height: 400px; width: 100%;">
    <div style="position: relative; display: flex; height:100%; align-items: center; justify-content: center">
    <div class="mamap-spinner" style="
        width: 40px; 
        height: 40px; 
        border: 4px solid rgba(0, 0, 0, 0.1); 
        border-top-color: #000; 
        border-radius: 50%; 
        animation: spin 1s linear infinite;">
    </div>
    </div>
    <style>
        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
    </style>
</div>';
}
add_shortcode('mamapio', 'mamap_embed_shortcode');
